@@ -18,6 +18,7 @@ import matplotlib.colors as mpl_col
 from matplotlib.ticker import StrMethodFormatter
 import copy
 import os
+import sys
 
 from . import utils as ut
 from . import gui
@@ -270,12 +271,13 @@ class Model(ABC):
         raise NotImplementedError
 
     @abstractmethod
-    def initial_params_from_experiment(self) -> None:
+    def initial_params_from_experiment(self, experiment: 'Experiment') -> None:
         """Finds guesses of initial fit parameters"""
         raise NotImplementedError
 
     @staticmethod
-    def from_experiments(experiments: list['Experiment']) -> list['Model']:
+    def from_experiments(experiments: list['Experiment'],
+                         verbose: bool = True) -> list['Model']:
         """
         Creates one model object per experiment, where the type of model
         is set according to user input based on cole cole plot
@@ -284,6 +286,8 @@ class Model(ABC):
         ----------
         experiments: list[Experiment]
             All experiments carried out at given value of dc field strength
+        verbose: bool, default False
+            If True, print initial parameter guesses to screen
 
         Returns
         ------
@@ -298,7 +302,10 @@ class Model(ABC):
         )
 
         # Get initial parameter values from coldest experiment
-        current_model.initial_params_from_experiment(experiments[0])
+        current_model.initial_params_from_experiment(
+            experiments[0],
+            verbose=verbose
+        )
 
         # Make copies of model, one per experiment
         models = [
@@ -397,7 +404,7 @@ class Model(ABC):
         plt.show()
 
         if modstore.model is None:
-            exit("Error: No Model Selected")
+            sys.exit("Error: No Model Selected")
 
         return modstore.model
 
@@ -1022,7 +1029,8 @@ class DebyeModel(Model):
 
         return is_flat
 
-    def initial_params_from_experiment(self, experiment: 'Experiment') -> None:
+    def initial_params_from_experiment(self, experiment: 'Experiment',
+                                       verbose: bool = False) -> None:
         """
         Generates initial guess of fitting parameters from experiment
 
@@ -1036,6 +1044,9 @@ class DebyeModel(Model):
         ----------
         experiment: Experiment
             Experiment object whose data is used for initial guesses
+        verbose: bool, default False
+            If True, print initial guesses to screen
+
         """
 
         # Mean of two lowest frequencies
@@ -1047,6 +1058,14 @@ class DebyeModel(Model):
             np.max(experiment.sus_re) - np.min(experiment.sus_re)
         ]
 
+        if verbose:
+            print(
+                '\nThe initial guesses are',
+                '\ntau = {}\nchi_S = {}\nchi_T = {}\n'.format(
+                    *self.initial_params
+                )
+            )
+
         return
 
     @staticmethod
@@ -1204,7 +1223,8 @@ class GeneralisedDebyeModel(Model):
 
         return is_flat
 
-    def initial_params_from_experiment(self, experiment: 'Experiment') -> None:
+    def initial_params_from_experiment(self, experiment: 'Experiment',
+                                       verbose: bool = False) -> None:
         """
         Generates initial guess of fitting parameters from experiment
 
@@ -1219,6 +1239,8 @@ class GeneralisedDebyeModel(Model):
         ----------
         experiment: Experiment
             Experiment object whose data is used for initial guesses
+        verbose: bool, default False
+            If True, print initial guesses to screen
         """
 
         # Mean of two lowest frequencies
@@ -1231,6 +1253,14 @@ class GeneralisedDebyeModel(Model):
             0.1
         ]
 
+        if verbose:
+            print(
+                '\nThe initial guesses are',
+                '\ntau = {}\nchi_S = {}\nchi_T = {}\nalpha = {}\n'.format(
+                    *self.initial_params
+                )
+            )
+
         return
 
     @staticmethod
@@ -1434,13 +1464,14 @@ class TwoMaximaModel(Model):
 
         return is_flat
 
-    def initial_params_from_experiment(self, experiment: 'Experiment') -> None:
+    def initial_params_from_experiment(self, experiment: 'Experiment',
+                                       verbose: bool = False) -> None:
         """
         Generates initial guess of fitting parameters from experiment
 
         Let x = largest frequency at turning point of imaginary susceptibility with largest abs value
 
-        Model params and guesses:
+        Parameters and guesses are
 
         tau_1 - inverse of frequency for turning point with 2nd largest imaginary susceptibility
 
@@ -1460,6 +1491,8 @@ class TwoMaximaModel(Model):
         ----------
         experiment: Experiment
             Experiment object whose data is used for initial guesses
+        verbose: bool, default False
+            If True, print initial guesses to screen
 
         Returns
         -------
@@ -1492,6 +1525,14 @@ class TwoMaximaModel(Model):
             np.min(experiment.sus_re)
         ]
 
+        if verbose:
+            print(
+                '\nThe initial guesses are',
+                '\ntau_1 = {}\ndelta_chi_1 = {}\nalpha_1 = {}\ntau_2 = {}\ndelta_chi_2 = {}\nalpha_2 = {}\nchi_total = {}'.format(
+                    *self.initial_params
+                )
+            )
+
         return
 
     @staticmethod
@@ -1785,7 +1826,7 @@ class Experiment():
     def from_measurements(cls,
                           measurements: list[Measurement],
                           temp_thresh: float = 0.1,
-                          field_thresh: float = 1e-8) -> list['Experiment']:
+                          field_thresh: float = 1e-8) -> list[list['Experiment']]:
         """
         Creates list of Experiment objecst from a list of individual
         Measurement objects. Experiments are defined as a set of measurements
@@ -1802,18 +1843,16 @@ class Experiment():
 
         Returns
         -------
-        list[Experiment]
-            Each element is an Experiment
-            i.e. a set of measurements with the same temperature and DC
-            field strength and the list is sorted low to high DC field then
-            low to high temperature
-            e.g.
-            0.1 Oe 25 K
-            0.1 Oe 50 K
-            ...
-            0.5 Oe 25 K
-            0.5 Oe 50 K
-        """
+        list[list[Experiment]]
+            Each element is a list of Experiments at the same DC field
+            sorted low to high DC field strength
+
+            Within each sublist the elements are single experiments
+            which are each a set of measurements with the same temperature
+            and DC field strength
+
+            The sublists are sorted low to high mean temperature.
+        """ # noqa
 
         # Sort measurements by dc field
         measurements.sort(key=lambda k: (k.dc_field, k.temperature))
@@ -2398,7 +2437,7 @@ def interactive_t_select(experiments: list[Experiment]):
     fig.canvas.mpl_disconnect(cid)
 
     if not len(experiments):
-        exit("No data selected")
+        sys.exit("No data selected")
 
     return experiments
 
