@@ -95,6 +95,14 @@ def ac_mode_func(args):
                 )
                 print('{} Frequencies: {}\n'.format(len(experiment.ac_freq), experiment.ac_freq))
 
+    # Manual selection of temperatures to fit
+    if args.select_T:
+        all_experiments_sep = [
+            ac.interactive_t_select(experiments)
+            for experiments in all_experiments_sep
+        ]
+        args.discard_off = True
+
     if args.process == "plot":
         for experiments in all_experiments_sep:
             ac.Experiment.plot_colecole(
@@ -109,14 +117,6 @@ def ac_mode_func(args):
             )
         exit()
 
-    # Manual selection of temperatures to fit
-    if args.select_T:
-        all_experiments_sep = [
-            ac.interactive_t_select(experiments)
-            for experiments in all_experiments_sep
-        ]
-        args.discard_off = True
-
     unique_dc_fields = np.unique(
         [experiment[0].dc_field for experiment in all_experiments_sep]
     )
@@ -636,16 +636,12 @@ def read_args(arg_list=None):
     # Hidden argument to signify that AC is being run by the executable
     # version of ccfit2
     if "--ccfit2_exe" in sys.argv:
-        parser.add_argument(
+        ac_parser.add_argument(
             '--ccfit2_exe',
             action='store_true',
             help=""
         )
 
-    args = parser.parse_args()
-
-    if "--ccfit2_exe" not in sys.argv:
-        args.run = False
 
     # Waveform
     description_Waveform = """
